@@ -133,9 +133,10 @@ def do_build_bootstrap(_project_name: str, _project_dir: str) -> None:
     if os.path.isfile(disable):
         return True
     if os.path.isfile("bootstrap"):
-        ret = subprocess.call(["bootstrap"])
+        ret = subprocess.call(["./bootstrap"])
         return ret == 0
-    print("not a boostrap folder (bootstrap not there)")
+    if ConfigOutput.print_not:
+        print("not a boostrap folder (bootstrap not there)")
     return True
 
 
@@ -143,13 +144,14 @@ def do_build_pydmt(_project_name: str, _project_dir: str) -> None:
     disable = ".build.disable"
     if os.path.isfile(disable):
         return True
-    if os.path.isfile(".pydmt.conf"):
+    if os.path.isfile(".pydmt.config"):
         ret = subprocess.call([
             "pydmt",
             "build",
         ])
         return ret == 0
-    print("not a pydmt folder (.pydmt.conf not there)")
+    if ConfigOutput.print_not:
+        print("not a pydmt folder (.pydmt.config not there)")
     return True
 
 
@@ -166,7 +168,8 @@ def do_build_venv_make(_project_name: str, _project_dir: str) -> None:
             "make",
         ])
         return ret == 0
-    print("not a make venv folder (either Makefile or .venv/default is not there)")
+    if ConfigOutput.print_not:
+        print("not a make venv folder (either Makefile or .venv/default is not there)")
     return True
 
 
@@ -177,7 +180,8 @@ def do_build_make(_project_name: str, _project_dir: str) -> None:
     if os.path.isfile("Makefile"):
         ret = subprocess.call(["make"])
         return ret == 0
-    print("not a make folder (Makefile not there)")
+    if ConfigOutput.print_not:
+        print("not a make folder (Makefile not there)")
     return True
 
 
